==> ogre-next-2.3.0-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/_ogre_profiler_8h.js <==
var _ogre_profiler_8h =
[
    [ "OgreProfile", "_ogre_profiler_8h.html#a1654899e6cfdec9f0972a45f3fa3fee7", null ],
    [ "OgreProfileBegin", "_ogre_profiler_8h.html#af9d7ab83c5a5d7de7579eebe9d27e53d", null ],
    [ "OgreProfileBeginDynamic", "_ogre_profiler_8h.html#ae7cb444157a082c7fa93a039d454eb1a", null ],
    [ "OgreProfileBeginDynamicHashed", "_ogre_profiler_8h.html#a05cfc4bd9ab13a9ebc47364bc1537427", null ],
    [ "OgreProfileBeginGPUEvent", "_ogre_profiler_8h.html#a7020187ac5635fa187ac6a690b5a5cbb", null ],
    [ "OgreProfileBeginGroup", "_ogre_profiler_8h.html#a76abda9b4a68907da2df018cd5253651", null ],
    [ "OgreProfileEnd", "_ogre_profiler_8h.html#a292ec22b5d851ef26fa9d7685c18b1f5", null ],
    [ "OgreProfileEndGPUEvent", "_ogre_profiler_8h.html#a6b57963334871478e3eb5804c61d40eb", null ],
    [ "OgreProfileEndGroup", "_ogre_profiler_8h.html#adc97ff9c6f56d0452bc0b1910bbab76a", null ],
    [ "OgreProfileExhaustive", "_ogre_profiler_8h.html#ae171c98240a36e0c7651e219850a280c", null ],
    [ "OgreProfileExhaustiveAggr", "_ogre_profiler_8h.html#a519462dca0d462d9cc1db84d00e70d63", null ],
    [ "OgreProfileGpuBegin", "_ogre_profiler_8h.html#a10bdb7d467e81cf4e630fa079bf5160d", null ],
    [ "OgreProfileGpuBeginDynamic", "_ogre_profiler_8h.html#afee174bfec52228cc366c4ba2173af27", null ],
    [ "OgreProfileGpuBeginDynamicHashed", "_ogre_profiler_8h.html#a37d5d3cc66d5aed4d4e2444fa9990774", null ],
    [ "OgreProfileGpuEnd", "_ogre_profiler_8h.html#a8bf0c807f241fc06f9fb7158a4756351", null ],
    [ "OgreProfileGroup", "_ogre_profiler_8h.html#af0b42a7cef7035e033b55dbd3196d07d", null ],
    [ "OgreProfileGroupAggregate", "_ogre_profiler_8h.html#a3699c5f0a4c7fe6689f2159c2c45818c", null ],
    [ "OgreProfileMarkGPUEvent", "_ogre_profiler_8h.html#ad2e159e927d57dc0c5009ec5eee861be", null ],
    [ "OgreProfilerUseStableMarkers", "_ogre_profiler_8h.html#aa89c5ebd69c406e66bc4fb54384827b5", null ],
    [ "ProfileGroupMask", "_ogre_profiler_8h.html#ga22a20f11c008a0d9b677fc2635922cfe", [
      [ "OGREPROF_USER_DEFAULT", "_ogre_profiler_8h.html#gga22a20f11c008a0d9b677fc2635922cfea721f30014dd7fbcd0bfb075ab74ab7d3", null ],
      [ "OGREPROF_ALL", "_ogre_profiler_8h.html#gga22a20f11c008a0d9b677fc2635922cfeade870d108856d0d9fbd27694bcb2242a", null ],
      [ "OGREPROF_GENERAL", "_ogre_profiler_8h.html#gga22a20f11c008a0d9b677fc2635922cfeaa62424531516cb168cd1865184eeb7a9", null ],
      [ "OGREPROF_CULLING", "_ogre_profiler_8h.html#gga22a20f11c008a0d9b677fc2635922cfea025771347fabdae9bb5db80f997ced2c", null ],
      [ "OGREPROF_RENDERING", "_ogre_profiler_8h.html#gga22a20f11c008a0d9b677fc2635922cfea1477e35ccd97730b18c1196a2f7fea64", null ]
    ] ]
];

==> ogre-next-2.3.1-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/_ogre_profiler_8h.js <==
var _ogre_profiler_8h =
[
    [ "OgreProfile", "_ogre_profiler_8h.html#a1654899e6cfdec9f0972a45f3fa3fee7", null ],
    [ "OgreProfileBegin", "_ogre_profiler_8h.html#af9d7ab83c5a5d7de7579eebe9d27e53d", null ],
    [ "OgreProfileBeginDynamic", "_ogre_profiler_8h.html#ae7cb444157a082c7fa93a039d454eb1a", null ],
    [ "OgreProfileBeginDynamicHashed", "_ogre_profiler_8h.html#a05cfc4bd9ab13a9ebc47364bc1537427", null ],
    [ "OgreProfileBeginGPUEvent", "_ogre_profiler_8h.html#a97a6287115e8702348063564054b11e3", null ],
    [ "OgreProfileBeginGroup", "_ogre_profiler_8h.html#a76abda9b4a68907da2df018cd5253651", null ],
    [ "OgreProfileEnd", "_ogre_profiler_8h.html#a292ec22b5d851ef26fa9d7685c18b1f5", null ],
    [ "OgreProfileEndGPUEvent", "_ogre_profiler_8h.html#a6d6e23a1680c65b151cb9ccf94428318", null ],
    [ "OgreProfileEndGroup", "_ogre_profiler_8h.html#adc97ff9c6f56d0452bc0b1910bbab76a", null ],
    [ "OgreProfileGpuBegin", "_ogre_profiler_8h.html#a10bdb7d467e81cf4e630fa079bf5160d", null ],
    [ "OgreProfileGpuBeginDynamic", "_ogre_profiler_8h.html#afee174bfec52228cc366c4ba2173af27", null ],
    [ "OgreProfileGpuBeginDynamicHashed", "_ogre_profiler_8h.html#a37d5d3cc66d5aed4d4e2444fa9990774", null ],
    [ "OgreProfileGpuEnd", "_ogre_profiler_8h.html#a8bf0c807f241fc06f9fb7158a4756351", null ],
    [ "OgreProfileGroup", "_ogre_profiler_8h.html#af0b42a7cef7035e033b55dbd3196d07d", null ],
    [ "OgreProfileGroupAggregate", "_ogre_profiler_8h.html#a3699c5f0a4c7fe6689f2159c2c45818c", null ],
    [ "OgreProfileGroupL", "_ogre_profiler_8h.html#ab51f0beb232bd094b71c444ed34ce859", null ],
    [ "OgreProfileGroupL2", "_ogre_profiler_8h.html#aa37898dc02a0bd0bbd5bd66c9bd593c7", null ],
    [ "OgreProfileL", "_ogre_profiler_8h.html#ad48af1a9aed2d82dab592a20cdc3142a", null ],
    [ "OgreProfileL2", "_ogre_profiler_8h.html#ae439852d4fefed65aeea0bdf18e0bb26", null ],
    [ "OgreProfileMarkGPUEvent", "_ogre_profiler_8h.html#ad2e159e927d57dc0c5009ec5eee861be", null ],
    [ "OgreProfilerUseStableMarkers", "_ogre_profiler_8h.html#aa89c5ebd69c406e66bc4fb54384827b5", null ],
    [ "ProfileGroupMask", "_ogre_profiler_8h.html#ga22a20f11c008a0d9b677fc2635922cfe", [
      [ "OGREPROF_USER_DEFAULT", "_ogre_profiler_8h.html#gga22a20f11c008a0d9b677fc2635922cfea721f30014dd7fbcd0bfb075ab74ab7d3", null ],
      [ "OGREPROF_ALL", "_ogre_profiler_8h.html#gga22a20f11c008a0d9b677fc2635922cfeade870d108856d0d9fbd27694bcb2242a", null ],
      [ "OGREPROF_GENERAL", "_ogre_profiler_8h.html#gga22a20f11c008a0d9b677fc2635922cfeaa62424531516cb168cd1865184eeb7a9", null ],
      [ "OGREPROF_CULLING", "_ogre_profiler_8h.html#gga22a20f11c008a0d9b677fc2635922cfea025771347fabdae9bb5db80f997ced2c", null ],
      [ "OGREPROF_RENDERING", "_ogre_profiler_8h.html#gga22a20f11c008a0d9b677fc2635922cfea1477e35ccd97730b18c1196a2f7fea64", null ]
    ] ]
];
